CurveArrow — pyqtgraph 0.11.0rc0 documentation

# CurveArrow

class `pyqtgraph.` `CurveArrow`(curve, index=0, pos=None, **opts)

  Provides an arrow that points to any specific sample on a PlotCurveItem. Provides properties that can be animated.

  `__init__`(curve, index=0, pos=None, **opts)

    Position can be set either as an index referring to the sample number or the position 0.0 - 1.0 If rotate is True, then the item rotates to match the tangent of the curve.